/*	
 *	audioPlayer() :: adds an audio player to a button
 *
 *	Copyright by Lazaworx
 *	http://www.lazaworx.com
 *	Author: Laszlo Molnar
 *
 *	Dual licensed under the MIT and GPL licenses.
 *	- http://www.opensource.org/licenses/mit-license.php
 *	- http://www.gnu.org/copyleft/gpl.html
 *
 *	Usage: $(element).addAudioPlayer(options);
 *	options:
 		autoPlay:	false,
 		loop:		true,
 		volume:		0.2,
 		source:		''			// pulled from data-src 'song1.mp3::song2.mp3'
 		
 */

(function($) {
	'use strict';
	
	$.fn.audioPlayer = function(settings) {
		
		settings = $.extend( {}, $.fn.audioPlayer.defaults, settings );
		var ns = '.ap',
			musicFolder = ((settings.rootPath === '.')? '' : (settings.rootPath + '/')) + settings.folder + '/';
				
		return this.each(function() {
				
			var self = $(this),
				player = $(),
				playList = $(),
				audio = $(),
				source = $(),
				curr = 0,
				songs,
				
				createPlayer = function() {
					player = $('<div>', {
							'class':	settings.playerHook
						});
					
					audio = $('<audio>', {
						preload: 	'auto',
						controls:	true
					}).appendTo(player);
					
					source = $('<source>', {
						src: musicFolder + songs[curr] 	
					}).appendTo(audio);
					
					audio.on('ended' + ns, function() {
						playNext();
						return true;
					});
					
					audio.on('pause' + ns, function() {
						self.removeClass('active');
					});
					
					audio.on('playing' + ns, function() {
						self.addClass('active');
					});
					
					if (songs.length) {
						playList = $('<ul>', {
							'class':	settings.playListHook
						}).appendTo(player);

						for (var i = 0; i < songs.length; i++) {
							playList.append($('<li>').append($('<a>', {
								text: decodeURIComponent(songs[i].replace(/\.[^\.]*$/, ''))
							}).on('click' + ns, function(e) {
								var i = playList.children().index($(e.target).parent());
								play(i);
								return false;
							})));
						}
						
						playList.children().eq(curr).addClass('active');
					}
				},
				
				setSource = function(n) {
					audio[0].pause();
					if (n >= songs.length || n < 0) {
						n %= songs.length;
					}
					source.attr({
						src: musicFolder + songs[n]
					})
					audio[0].load();
					curr = n;
					playList.children().removeClass('active');
					playList.children().eq(n).addClass('active');
				},
				
				play = function(n) {
					if (typeof n === 'undefined' || typeof n === $.event) {
						n = curr;
					}
					if (!source.attr('src') || n !== curr) {
						setSource(n);
					}
					audio[0].play();
					self.addClass('active');
				},
				
				playNext = function() {
					if (curr >= songs.length - 1) {
						if (settings.loop) {
							play(0);
						}
					} else {
						play(curr + 1);
					}
				},
				
				pause = function() {
					audio[0].pause();
					self.removeClass('active');
				},
				
				destroy = function() {
					player.trigger('removeTooltip');
					player.add(self).off(ns);
					player.remove();
				},
				
				// Saving play status
			
				saveStatus = function() {
					if ( $.cookie ) {						
						$.cookie('ap-status', 
							(audio[0].paused? '0':'1') + 
							'::' + (audio[0].currentTime || 0) + 
							'::' + (audio[0].volume || settings.volume) +
							(curr? ('::' + curr) : '')
						);
					}
				},
				
				// Loading play status
				
				loadStatus = function() {
					if ( $.cookie ) {
						var c = $.cookie('ap-status');
						if ( c ) {
							c = c.split('::');
							settings.autoPlay = (c[0] === '1');
							settings.startTime = parseInt(c[1] || 0, 10);
							settings.volume = parseFloat(c[2]);
							curr = parseInt(c[3] || 0, 10);
							if (curr < 0 || curr > songs.length) {
								curr = 0;
							}
						}
					}
				};
						
			// Loading playlist 
			if (self.data('src')) {
				songs = self.data('src').split('::');
			} else if (settings.hasOwnProperty('source')) {
				songs = settings.source.split('::');
			} else {
				return;
			}
			
			// Load status to initialize, save status on unload
			if ( settings.saveStatus ) {
				loadStatus();
				$(window).on('unload', saveStatus);
			}
			
			// Creating the AUDIO element
			createPlayer();
			
			// Attaching as tooltip
			self.addTooltip(player);
			
			// Play/Pause button functionality 
			self.on('click' + ns, function() {
				if (self.hasClass('active')) {
					pause();
				} else {
					play();
				}
				return false;
			});
			
			// Events for outside control
			
			self.on('removePlayer' + ns, destroy);
			
			self.on('pausePlayer' + ns, function() {
				pause();
			});
			
			self.on('startPlayer' + ns, function() {
				play();
			});
			
			// Delaying the player initialization for the sake of Firefox
			
			setTimeout(function() {
					
				audio[0].volume = settings.volume;
					
				if (settings.hasOwnProperty('startTime')) {
					audio[0].currentTime = settings.startTime;
				}						

				// Start playing if Auto on
				if (settings.autoPlay) {
					play();
				}
				
			}, 50);
			
		});
		
	};
	
	$.fn.audioPlayer.defaults = {
		autoPlay:		true,
		loop:			true,
		volume:			0.2,
		saveStatus:		true,
		playerHook: 	'player',
		playListHook:	'play-list',
		folder:			'_music'
	};
	
})(jQuery);

/* Audio API
	error
	src
	currentSrc
	crossOrigin
	networkState
	preload
	buffered
	readyState
	seeking
	currentTime
	duration
	paused
	defaultPlaybackRate
	playbackRate
	played
	seekable
	ended
	autoplay
	loop
	controls
	volume
	muted
	defaultMuted
	textTracks
	webkitAudioDecodedByteCount
	webkitVideoDecodedByteCount
	load
	play
	pause
	addTextTrack
	canPlayType
	NETWORK_EMPTY
	NETWORK_IDLE
	NETWORK_LOADING
	NETWORK_NO_SOURCE
	HAVE_NOTHING
	HAVE_METADATA
	HAVE_CURRENT_DATA
	HAVE_FUTURE_DATA
	HAVE_ENOUGH_DATA
	onwebkitkeyadded
	onwebkitkeyerror
	onwebkitkeymessage
	onwebkitneedkey
	mediaKeys
	onencrypted
	webkitGenerateKeyRequest
	webkitAddKey
	webkitCancelKeyRequest
	setMediaKeys
	title
	lang
	translate
	dir
	dataset
	hidden
	tabIndex
	accessKey
	draggable
	spellcheck
	contentEditable
	isContentEditable
	offsetParent
	offsetTop
	offsetLeft
	offsetWidth
	offsetHeight
	style
	innerText
	outerText
	webkitdropzone
	onabort
	onblur
	oncancel
	oncanplay
	oncanplaythrough
	onchange
	onclick
	onclose
	oncontextmenu
	oncuechange
	ondblclick
	ondrag
	ondragend
	ondragenter
	ondragleave
	ondragover
	ondragstart
	ondrop
	ondurationchange
	onemptied
	onended
	onerror
	onfocus
	oninput
	oninvalid
	onkeydown
	onkeypress
	onkeyup
	onload
	onloadeddata
	onloadedmetadata
	onloadstart
	onmousedown
	onmouseenter
	onmouseleave
	onmousemove
	onmouseout
	onmouseover
	onmouseup
	onmousewheel
	onpause
	onplay
	onplaying
	onprogress
	onratechange
	onreset
	onresize
	onscroll
	onseeked
	onseeking
	onselect
	onshow
	onstalled
	onsubmit
	onsuspend
	ontimeupdate
	ontoggle
	onvolumechange
	onwaiting
	click
	focus
	blur
	onautocomplete
	onautocompleteerror
	namespaceURI
	prefix
	localName
	tagName
	id
	className
	classList
	attributes
	innerHTML
	outerHTML
	shadowRoot
	scrollTop
	scrollLeft
	scrollWidth
	scrollHeight
	clientTop
	clientLeft
	clientWidth
	clientHeight
	onbeforecopy
	onbeforecut
	onbeforepaste
	oncopy
	oncut
	onpaste
	onsearch
	onselectstart
	onwheel
	onwebkitfullscreenchange
	onwebkitfullscreenerror
	previousElementSibling
	nextElementSibling
	children
	firstElementChild
	lastElementChild
	childElementCount
	hasAttributes
	getAttribute
	getAttributeNS
	setAttribute
	setAttributeNS
	removeAttribute
	removeAttributeNS
	hasAttribute
	hasAttributeNS
	getAttributeNode
	getAttributeNodeNS
	setAttributeNode
	setAttributeNodeNS
	removeAttributeNode
	closest
	matches
	getElementsByTagName
	getElementsByTagNameNS
	getElementsByClassName
	insertAdjacentHTML
	createShadowRoot
	getDestinationInsertionPoints
	requestPointerLock
	getClientRects
	getBoundingClientRect
	scrollIntoView
	insertAdjacentElement
	insertAdjacentText
	scrollIntoViewIfNeeded
	webkitMatchesSelector
	animate
	remove
	webkitRequestFullScreen
	webkitRequestFullscreen
	querySelector
	querySelectorAll
	nodeType
	nodeName
	baseURI
	ownerDocument
	parentNode
	parentElement
	childNodes
	firstChild
	lastChild
	previousSibling
	nextSibling
	nodeValue
	textContent
	hasChildNodes
	normalize
	cloneNode
	isEqualNode
	compareDocumentPosition
	contains
	lookupPrefix
	lookupNamespaceURI
	isDefaultNamespace
	insertBefore
	appendChild
	replaceChild
	removeChild
	isSameNode
	ELEMENT_NODE
	ATTRIBUTE_NODE
	TEXT_NODE
	CDATA_SECTION_NODE
	ENTITY_REFERENCE_NODE
	ENTITY_NODE
	PROCESSING_INSTRUCTION_NODE
	COMMENT_NODE
	DOCUMENT_NODE
	DOCUMENT_TYPE_NODE
	DOCUMENT_FRAGMENT_NODE
	NOTATION_NODE
	DOCUMENT_POSITION_DISCONNECTED
	DOCUMENT_POSITION_PRECEDING
	DOCUMENT_POSITION_FOLLOWING
	DOCUMENT_POSITION_CONTAINS
	DOCUMENT_POSITION_CONTAINED_BY
	DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC
	addEventListener
	removeEventListener
	dispatchEvent
*/